@@ -262,7 +262,7 @@ void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     /* Save product */
     fors_dfs_save_image_err(frames, master_bias, MASTER_BIAS,
-                        qc, parameters, fors_bias_name, 
+                        qc, NULL, parameters, fors_bias_name, 
                         cpl_frameset_get_position(bias_frames, 0));
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             MASTER_BIAS);
@@ -292,50 +292,36 @@ fors_bias_stack(const fors_image_list *images, const stack_method *sm)
     hdrl_parameter * stackmethod_par = NULL;
     hdrl_imagelist * images_hdrl = NULL;
     hdrl_image * master_bias_hdrl = NULL;
+    //Create parameters based on method
     switch (sm->method) {
     case stack_method::MEAN :
         stackmethod_par = hdrl_collapse_mean_parameter_create();
-        images_hdrl = fors_image_list_to_hdrl(images);
-        hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
-                                &contrib);
-        cpl_image_delete(contrib);
-        master_bias = fors_image_from_hdrl(master_bias_hdrl);
         break;
     case stack_method::WMEAN :
         stackmethod_par = hdrl_collapse_weighted_mean_parameter_create();
-        images_hdrl = fors_image_list_to_hdrl(images);
-        hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
-                                &contrib);
-        cpl_image_delete(contrib);
-        master_bias = fors_image_from_hdrl(master_bias_hdrl);
         break;
     case stack_method::MEDIAN : 
         stackmethod_par = hdrl_collapse_median_parameter_create();
-        images_hdrl = fors_image_list_to_hdrl(images);
-        hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
-                                &contrib);
-        cpl_image_delete(contrib);
-        master_bias = fors_image_from_hdrl(master_bias_hdrl);
         break;
     case stack_method::MINMAX :
-        master_bias = fors_image_collapse_minmax_create(images, 
-                                  sm->pars.minmax.min_reject,
-                                  sm->pars.minmax.max_reject);
+        stackmethod_par = hdrl_collapse_minmax_parameter_create(
+                sm->pars.minmax.min_reject, sm->pars.minmax.max_reject);
         break;
     case stack_method::KSIGMA : 
         stackmethod_par = hdrl_collapse_sigclip_parameter_create
           (sm->pars.ksigma.klow, sm->pars.ksigma.khigh, sm->pars.ksigma.kiter);
-        images_hdrl = fors_image_list_to_hdrl(images);
-        hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
-                                &contrib);
-        cpl_image_delete(contrib);
-        master_bias = fors_image_from_hdrl(master_bias_hdrl);
         break;
     default:
         assure( false, return NULL, "Unknown stack method '%s' (%d)",
                 fors_stack_method_get_string(sm), sm->method);
         break;
     }
+    //Do the stacking
+    images_hdrl = fors_image_list_to_hdrl(images);
+    hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
+                            &contrib);
+    cpl_image_delete(contrib);
+    master_bias = fors_image_from_hdrl(master_bias_hdrl);
     
     if(stackmethod_par != NULL)
         hdrl_parameter_destroy(stackmethod_par);
@@ -376,6 +362,7 @@ void fors_bias_compute_ron
 #undef cleanup
 #define cleanup \
 do { \
+    fors_image_delete(&first_bias_raw); \
     fors_image_delete(&image); \
 } while (0)
 
@@ -393,10 +380,10 @@ write_qc(cpl_propertylist *qc,
     fors_image *image = NULL;
 
     (void)setting; //Avoid compiler warning
-    (void)first_bias; //Avoid compiler warning
 
+    fors_image * first_bias_raw = fors_image_load(first_bias);
     fors_header_write_double(qc,
-                            fors_image_get_median(first_raw, NULL),
+                            fors_image_get_median(first_bias_raw, NULL),
                             "QC.BIAS.LEVEL",
                             "ADU",
                             "Bias level");
