@@ -273,6 +273,9 @@ fors_dfs_set_groups(cpl_frameset * set)
                 strcmp(tag, SKY_FLAT_IMG      ) == 0 ||
                 strcmp(tag, STANDARD_IMG      ) == 0 ||
                 strcmp(tag, "LAMP_PMOS"       ) == 0 ||
+                strcmp(tag, "LAMP_MXU"       ) == 0 ||
+                strcmp(tag, "LAMP_MOS"       ) == 0 ||
+                strcmp(tag, "LAMP_LSS"       ) == 0 ||
                 strcmp(tag, "SCREEN_FLAT_PMOS") == 0 ||
                 strcmp(tag, "STANDARD_PMOS"   ) == 0 ||
                 strcmp(tag, "SCIENCE_PMOS"    ) == 0 ||
@@ -992,6 +995,7 @@ cpl_propertylist *dfs_load_header(cpl_frameset *frameset,
 static void
 dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
          const char *category, cpl_propertylist *header,
+         cpl_propertylist *extra_header,
          const cpl_parameterlist *parlist, const char *recipename,
          const cpl_frame *inherit_frame)
 {
@@ -1022,7 +1026,7 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
             cpl_frame_get_filename(inherit_frame);
         
         raw_header = cpl_propertylist_load(raw_filename, 0);
-        if (cpl_error_get_code() != CPL_ERROR_NONE) {
+        if (raw_header == NULL) {
             cpl_msg_error(cpl_func, "Could not read %s primary header", raw_filename);
             return;
         }
@@ -1066,7 +1070,7 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
     if (header == NULL)
         plist = cpl_propertylist_new();
     else
-        plist = header;
+        plist = cpl_propertylist_duplicate(header);
 
     if (cpl_dfs_setup_product_header(plist, frame, frameset, parlist,
                                      recipename, version, "PRO-1.15", 
@@ -1075,8 +1079,7 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
                       cpl_error_get_where(), cpl_error_get_message());
         cpl_msg_error(cpl_func, "Problem with product %s FITS header definition",
                       category);
-        if (header == NULL)
-            cpl_propertylist_delete(plist);
+        cpl_propertylist_delete(plist);
         cpl_frame_delete(frame);
         cpl_free(filename);
         cpl_free((void *)version);
@@ -1090,7 +1093,7 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
      */
     
     if (type == FORS_TYPE_IMAGE_ERR) {
-        fors_image_save((fors_image *)object, plist, filename);
+        fors_image_save((fors_image *)object, plist, extra_header, filename);
     }
     else if (type == FORS_TYPE_IMAGE) {
         cpl_image_save((cpl_image *)object, filename, CPL_BPP_IEEE_FLOAT, plist,
@@ -1105,15 +1108,13 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
         cpl_msg_error(cpl_func, "Error found in %s: %s",
                       cpl_error_get_where(), cpl_error_get_message());
         cpl_msg_error(cpl_func, "Cannot save product %s to disk", filename);
-        if (header == NULL)
-            cpl_propertylist_delete(plist);
+        cpl_propertylist_delete(plist);
         cpl_frame_delete(frame);
         cpl_free(filename);
         return;
     }
 
-    if (header == NULL)
-        cpl_propertylist_delete(plist);
+    cpl_propertylist_delete(plist);
 
     cpl_free(filename);
 
@@ -1151,7 +1152,7 @@ fors_dfs_save_image(cpl_frameset *frameset, const cpl_image *image,
                     const cpl_frame *inherit_frame)
 {
     dfs_save(frameset, image, FORS_TYPE_IMAGE, 
-             category, header, 
+             category, header, NULL, 
              parlist, recipename, 
              inherit_frame);
 }
@@ -1190,7 +1191,7 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
     cpl_propertylist * extension_header;
 
     dfs_save(frameset, image, FORS_TYPE_IMAGE, 
-             category, header, 
+             category, header, NULL, 
              parlist, recipename, 
              inherit_frame);
     
@@ -1235,11 +1236,12 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
 void
 fors_dfs_save_image_err(cpl_frameset *frameset, const fors_image *image,
                     const char *category, cpl_propertylist *header,
+                    cpl_propertylist *err_header,
                     const cpl_parameterlist *parlist, const char *recipename,
                     const cpl_frame *inherit_frame)
 {
     dfs_save(frameset, image, FORS_TYPE_IMAGE_ERR, 
-             category, header, 
+             category, header, err_header, 
              parlist, recipename, 
              inherit_frame);
 }
@@ -1279,7 +1281,7 @@ fors_dfs_save_image_err_mask(cpl_frameset *frameset, const fors_image *image,
     cpl_propertylist * extension_header;
         
     dfs_save(frameset, image, FORS_TYPE_IMAGE_ERR, 
-             category, header, 
+             category, header, NULL, 
              parlist, recipename, 
              inherit_frame);
     
@@ -1408,7 +1410,7 @@ fors_dfs_save_table(cpl_frameset *frameset, const cpl_table *table,
                     const cpl_frame *inherit_frame)
 {
     dfs_save(frameset, table, FORS_TYPE_TABLE, 
-             category, header, 
+             category, header, NULL, 
              parlist, recipename, 
              inherit_frame);
 }
