@@ -37,9 +37,9 @@ CPL_BEGIN_DECLS
 /* Types of data to save */
 enum _fors_type_ {
 
-    FORS_TYPE_IMAGE      = 1 << 0,
-    FORS_TYPE_IMAGE_ERR  = 1 << 1,
-    FORS_TYPE_TABLE      = 1 << 2
+    FORS_TYPE_IMAGE          = 1 << 0,
+    FORS_TYPE_IMAGE_ERR      = 1 << 1,
+    FORS_TYPE_TABLE          = 1 << 2
 };
 
 typedef enum _fors_type_ fors_type;
@@ -83,7 +83,6 @@ void fors_dfs_set_groups(cpl_frameset * set);
 const char *fors_dfs_pipeline_version(const cpl_propertylist *header, 
 				      const char **instrument_version);
 char *dfs_generate_filename(const char *);
-char *dfs_generate_filename_tfits(const char *);
 int dfs_get_parameter_bool(cpl_parameterlist *, const char *, 
                            const cpl_table *);
 int dfs_get_parameter_int(cpl_parameterlist *, const char *, 
@@ -104,6 +103,12 @@ void fors_dfs_add_wcs(cpl_propertylist *header, const cpl_frame *frame,
 void fors_dfs_add_exptime(cpl_propertylist *header, const cpl_frame *frame,
                           double exptime);
 void fors_dfs_save_image_err(cpl_frameset *frameset, const fors_image *image,
+             const char *category, cpl_propertylist *header,
+             cpl_propertylist *err_header,
+             const cpl_parameterlist *parlist, const char *recipename,
+             const cpl_frame *raw_frame);
+void fors_dfs_save_image_err_mask(cpl_frameset *frameset, 
+             const fors_image *image, const cpl_image *mask,
              const char *category, cpl_propertylist *header,
              const cpl_parameterlist *parlist, const char *recipename,
              const cpl_frame *raw_frame);
@@ -111,6 +116,11 @@ void fors_dfs_save_image(cpl_frameset *frameset, const cpl_image *image,
              const char *category, cpl_propertylist *header,
              const cpl_parameterlist *parlist, const char *recipename,
              const cpl_frame *raw_frame);
+void fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
+                         const cpl_image *mask, const char *category, 
+                         cpl_propertylist *header, 
+                         const cpl_parameterlist *parlist, const char *recipename,
+                         const cpl_frame *inherit_frame);
 void fors_dfs_save_image_wcs(cpl_frameset *frameset, const fors_image *image,
 			     const char *category, cpl_propertylist *header,
 			     const cpl_parameterlist *parlist, const char *recipename,
@@ -137,11 +147,6 @@ cpl_error_code dfs_save_image_null(cpl_frameset *, cpl_parameterlist *,
 				   const char *, const char *,
 				   const char *);
 
-cpl_frameset * hawki_extract_frameset(
-        const cpl_frameset  *   in,
-        const char          *   tag);
-
-
 CPL_END_DECLS
 
 #endif   /* FORS_DFS_H */
