@@ -445,7 +445,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     fors_dfs_add_exptime(product_header, cpl_frameset_get_position(sci_frame, 0), 0.);
 
     fors_dfs_save_image_err(frames, sci, SCIENCE_REDUCED_IMG,
-                        qc, parameters, fors_img_science_name, 
+                        qc, NULL, parameters, fors_img_science_name, 
                         cpl_frameset_get_position(sci_frame, 0));
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             SCIENCE_REDUCED_IMG);
