@@ -35,8 +35,8 @@
 #define MAX_COLNAME      (80)
 
 cpl_table * fors_compute_response
-(cpl_image *spectra, cpl_image * mapped_flat_disp_profile,
- cpl_propertylist *flat_disp_header, cpl_table *objects,
+(cpl_image *spectra, cpl_image * mapped_flat_sed,
+ cpl_propertylist *flat_sed_header, cpl_table *objects,
  double startwave, double dispersion, double gain,
  double exptime, cpl_table *ext_table, double airmass, cpl_table *flux_table,
  const std::vector<double>& ignored_waves,
@@ -89,17 +89,13 @@ cpl_table * fors_compute_response
      * Find brightest spectrum and duplicate it.
      */
     cpl_size obj_slit = -1;
-    if (ny == 1) {
-        spectrum = cpl_image_duplicate(spectra);
-        obj_slit = 0;
-    }
-    else {
+    {
         cpl_size        maxpos_x, maxpos_y;
         cpl_image *brights = cpl_image_collapse_create(spectra, 1);
 
         cpl_image_get_maxpos(brights, &maxpos_x, &maxpos_y);
 
-        if(mapped_flat_disp_profile != NULL)
+        if(mapped_flat_sed != NULL)
         {
             /* Identify the slit of this object which will be stored in obj_slit*/
             //TODO: Move it away from here. It is also repeated in the science photometric correction
@@ -135,13 +131,13 @@ cpl_table * fors_compute_response
     //TODO: This modifies the observed standard spectra. The correction should be applied only at response computation time.
     //It has an impact, since the resp.observed_flux() is saved in the response product.
     cpl_image * spectrum_sedcorr = NULL;
-    if(mapped_flat_disp_profile != NULL)
+    if(mapped_flat_sed != NULL)
     {
         spectrum_sedcorr = cpl_image_duplicate(spectrum);
         for (int i_pix = 0; i_pix < nx; i_pix++)
         {
             int   null;
-            double profile_val  = cpl_image_get(mapped_flat_disp_profile, i_pix+1, obj_slit+1, &null);
+            double profile_val  = cpl_image_get(mapped_flat_sed, i_pix+1, obj_slit+1, &null);
             if(profile_val != 0)
                 cpl_image_set(spectrum_sedcorr, i_pix+1, 1, 
                         cpl_image_get(spectrum_sedcorr, i_pix+1, 1, &null) / profile_val);
@@ -149,9 +145,11 @@ cpl_table * fors_compute_response
         std::ostringstream norm_key;
         norm_key<< "ESO QC FLAT SED"<<obj_slit+1<<" NORM";
         flat_sed_norm_factor = 
-          cpl_propertylist_get_double(flat_disp_header, norm_key.str().c_str());
+          cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         if(cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND)
         {
+            cpl_image_delete(spectrum);
+            cpl_image_delete(spectrum_sedcorr);
             std::string error_msg("Could not find keyword in flat sed: ");
             throw std::runtime_error(error_msg+norm_key.str());
         }
@@ -179,7 +177,7 @@ cpl_table * fors_compute_response
     resp.compute_response(std_extcorrect, std_star);
 
     /* Do the same for the SED correction */
-    if(mapped_flat_disp_profile != NULL)
+    if(mapped_flat_sed != NULL)
     {
         /* Convert standard star spectrum in electrons per second per Angstrom. */
         cpl_image_multiply_scalar(spectrum_sedcorr, gain / exptime / dispersion);
@@ -202,7 +200,7 @@ cpl_table * fors_compute_response
             resp.fit_response_spline(nknots, ignored_waves, ignored_wave_ranges);
         else if(degree > 0 )
             resp.fit_response_pol(degree, ignored_waves, ignored_wave_ranges);
-        if(mapped_flat_disp_profile != NULL)
+        if(mapped_flat_sed != NULL)
         {
             if(nknots > 0 )
                 resp_sedcorr.fit_response_spline(nknots, ignored_waves, ignored_wave_ranges);
@@ -285,7 +283,7 @@ cpl_table * fors_compute_response
     cpl_table_set_column_unit(response_interp, "EFFICIENCY", "electron/photon");
     cpl_table_copy_data_double(response_interp, "EFFICIENCY", &(resp.efficiency_fit_obs()[0]));
 
-    if(mapped_flat_disp_profile != NULL)
+    if(mapped_flat_sed != NULL)
     {
         cpl_table_new_column(response_table, "OBS_FLUX_FFSED", CPL_TYPE_DOUBLE);
         cpl_table_set_column_unit(response_table, "OBS_FLUX_FFSED", "electron/(s Angstrom)");
