@@ -239,7 +239,7 @@ void fors_zeropoint(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_table *aligned_phot = NULL;
     cpl_propertylist *qc_phot = NULL;
     cpl_propertylist *qc_sources = NULL;
-    double zeropoint, dzeropoint;
+    double zeropoint = 0.0, dzeropoint;
     fors_extract_sky_stats sky_stats;
     cpl_image *background = NULL;
     cpl_table *sources    = NULL;
@@ -331,13 +331,13 @@ void fors_zeropoint(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Done finding frames */
 
     /* Get setting */
-    setting = fors_setting_new(cpl_frameset_get_first(std_frame));
+    setting = fors_setting_new(cpl_frameset_get_position(std_frame, 0));
     assure( !cpl_error_get_code(), return, "Could not get instrument setting" );
     
     /* Load std raw frame header */
     raw_header = cpl_propertylist_load(
                     cpl_frame_get_filename(
-                        cpl_frameset_get_first(std_frame)), 0);
+                        cpl_frameset_get_position(std_frame, 0)), 0);
     if (raw_header == NULL) {
         cpl_msg_error(cpl_func, "Failed to load raw header");
         cleanup;
@@ -642,7 +642,7 @@ Moved outside by Carlo - end */
     
     /* FIXME: FAP: use WCS corrected header */
     fors_dfs_save_image_err(frames, std, STANDARD_REDUCED_IMG,
-                        product_header, parameters, fors_zeropoint_name, 
+                        product_header, NULL, parameters, fors_zeropoint_name, 
                         cpl_frameset_get_position(std_frame, 0));
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             STANDARD_REDUCED_IMG);
@@ -720,7 +720,7 @@ Moved outside by Carlo - end */
         }
         /* FIXME: FAP: use WCS corrected header */
         fors_dfs_save_image_err(frames, std, "DEBUG",
-                            product_header, parameters, fors_zeropoint_name, 
+                            product_header, NULL, parameters, fors_zeropoint_name, 
                             cpl_frameset_get_position(std_frame, 0));
         assure( !cpl_error_get_code(), return, "Saving %s failed",
                 "DEBUG");
