@@ -55,8 +55,8 @@ void mosca::response::compute_response
 
     for(size_t ibin = 0; ibin < std_flux.size() ; ++ibin)
     {
-        //TODO: the 0.0026 is hardcoded, and depends on telescope area 
-        //see moses.c   
+        //TODO: the 0.0026 [cm^2/(erg Angstrom)] is hardcoded, and depends on telescope area 
+        //see moses.c  
         //Get the wavelength range
         double wave_bin_start = std_wave[ibin] - std_binsize[ibin] / 2.;
         double wave_bin_end   = std_wave[ibin] + std_binsize[ibin] / 2.;
@@ -66,7 +66,7 @@ void mosca::response::compute_response
             observed_spectrum.integrate(wave_bin_start, wave_bin_end, true, 0.5) /
                std_binsize[ibin];
         double wavelength = std_wave[ibin];
-        double std_flux_bin_phys = std_flux[ibin] * 0.0026 * wavelength;
+        double std_flux_bin_phys = std_flux[ibin] * 0.0026 * wavelength; //[photons/s]
         double efficiency = obs_std_flux_bin / std_flux_bin_phys;
         double respon;
         if(obs_std_flux_bin != 0)
