@@ -93,15 +93,17 @@ try:
       if self.flat_norm is not None and self.lamp_reduced is not None \
          and self.disp_residuals is not None and self.flat_mscreen is not None \
          and self.detected_lines is not None:
+        gs = matplotlib.gridspec.GridSpec(80,2)
         if self.slit_map is not None:
-          self.subplot_slit_map       = figure.add_subplot(3,2,2)
-          self.subplot_lamp_reduced   = figure.add_subplot(3,2,1)
+          self.subplot_slit_map       = figure.add_subplot(gs[0:19,1:2])
+          self.subplot_lamp_reduced   = figure.add_subplot(gs[0:19,0:1])
         else:
-          self.subplot_lamp_reduced   = figure.add_subplot(3,1,1)
-        self.subplot_line_x_y       = figure.add_subplot(3,2,3)
-        self.subplot_flat_raw       = figure.add_subplot(3,2,4)
-        self.subplot_line_res_wave  = figure.add_subplot(3,2,5)
-        self.subplot_flat_norm      = figure.add_subplot(3,2,6)
+          self.subplot_lamp_reduced   = figure.add_subplot(gs[0:19,0:2])
+        self.subplot_line_x_y       = figure.add_subplot(gs[26:46,0:1])
+        self.subplot_flat_raw       = figure.add_subplot(gs[26:46,1:2])
+        self.subplot_line_res_wave  = figure.add_subplot(gs[54:74,0:1])
+        self.subplot_flat_norm      = figure.add_subplot(gs[54:74,1:2])
+        self.subplot_txtinfo        = figure.add_subplot(gs[75:80,0:2])
       else : 
         self.subtext_nodata      = figure.add_subplot(1,1,1)
           
@@ -135,6 +137,9 @@ try:
         #Line positions X vs Y
         self.plotLinePositions()
         
+        #Additional text info
+        self.showTextInfo()
+
       else :
         #Data not found info
         self.showNoData()
@@ -199,6 +204,38 @@ the dispersion relation there will be extrapolated."""
       self.detected_lines.plotXVsY(self.subplot_line_x_y,
                                    title_line_x_y, tooltip_line_x_y)
 
+    def showTextInfo(self) :
+      self.subplot_txtinfo.set_axis_off()
+      try:
+        grism = self.lamp_reduced.arc.readKeyword('HIERARCH ESO INS GRIS1 NAME')
+      except:
+        grism = 'unkown'
+      try:
+        filter_name = self.lamp_reduced.arc.readKeyword('HIERARCH ESO INS FILT1 NAME')
+      except:
+        filter_name = 'free'
+      self.subplot_txtinfo.text(0.1, 0., 'Grism/Filter: '+grism+"/"+
+                                filter_name, 
+                                ha='left', va='center', weight='bold')
+      try:
+        slit = self.lamp_reduced.arc.readKeyword('HIERARCH ESO INS SLIT NAME')
+        self.subplot_txtinfo.text(0.5, 0., 'Slit name (LSS): '+slit, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        checksum = self.lamp_reduced.arc.readKeyword('HIERARCH ESO INS MOS CHECKSUM')
+        self.subplot_txtinfo.text(0.5, 0., 'Slits checksum (MOS): '+str(checksum), 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        mask_id = self.lamp_reduced.arc.readKeyword('HIERARCH ESO INS MASK ID')
+        self.subplot_txtinfo.text(0.5, 0., 'Mask id (MXU): '+mask_id, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+
     def showNoData(self) :
       self.subtext_nodata.set_axis_off()
       self.text_nodata = 'Calibrations not found in the products'
