@@ -230,7 +230,6 @@ class PlotableDispResiduals :
     self.resdisplay.display(subplot, title, tooltip, self.allypos,
                             self.allresiduals)
   def getClosestLine(self, wave_selected) :
-    
     distance = numpy.fabs(self.wave - wave_selected)
     idx = numpy.nanargmin(distance)
     return self.wave[idx]
@@ -398,21 +397,21 @@ class PlotableSpecPhot :
     self.raw_response_used = self.raw_response[self.used_fit > 0]    
 
   def plotResponse(self, subplot, title, tooltip):
-    self.respdisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) e-)')
+    self.respdisp.setLabels('$\lambda\, [\AA]$','$10^{-16} erg\, cm^{-2} e-^{-1}$')
     self.respdisp.flux_lim = 0., numpy.max(self.raw_response_nonnull) * 1.1
     self.respdisp.display(subplot, title, tooltip, self.wave_obs, self.fit_response, autolimits = False)
     subplot.scatter(self.wave_nonnull, self.raw_response_nonnull, color='darkblue')
     subplot.scatter(self.wave_used, self.raw_response_used, color='lightgreen')
 
   def plotStdExtracted(self, subplot, title, tooltip):
-    self.respdisp.setLabels('Angstrom','e-/ (s Angstrom)')
+    self.respdisp.setLabels('$\lambda\, [\AA]$','$e-\, s^{-1} \AA^{-1}$')
     std_obs_flux_nonnull = self.std_obs_flux[self.std_obs_flux > 0]
     wave_nonnull = self.wave[self.std_obs_flux > 0]
     self.respdisp.display(subplot, title, tooltip,
                           wave_nonnull, std_obs_flux_nonnull, autolimits = True)
 
   def plotStdTabulated(self, subplot, title, tooltip):
-    self.tabdisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) e-)')
+    self.tabdisp.setLabels('$\lambda\, [\AA]$','$10^{-16} erg\,  cm^{-2} s^{-1} \AA-^{-1}$')
     self.tabdisp.display(subplot, title, tooltip, self.wave, self.std_ref_flux)
 
 class PlotableStdTabRedFlux :
@@ -435,7 +434,7 @@ class PlotableStdTabRedFlux :
     
 
   def plotStdTabRedFlux(self, subplot, title, tooltip) :
-    self.tabstddisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) Angstrom)')
+    self.tabstddisp.setLabels('$\lambda\, [\AA]$','$10^{-16} erg\, cm^{-2} s^{-1} \AA^{-1}$')
     self.tabstddisp.setLimits(self.reducedfluxstd.wave[0],
                               self.reducedfluxstd.wave[len(self.reducedfluxstd.wave)-1],
                               0.,
@@ -450,7 +449,7 @@ class PlotableStdTabRedFlux :
 
 
   def plotStdRed(self, subplot, title, tooltip) :
-    self.stdreddisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) Angstrom)')
+    self.stdreddisp.setLabels('$\lambda\, [\AA]$','$ADU/s$')
     self.stdreddisp.setLimits(self.reducedstd.wave[0],
                               self.reducedstd.wave[len(self.reducedstd.wave)-1],
                               0.,
