@@ -72,9 +72,11 @@ try:
     # Note also that the last one is actually a box with text, no graphs.
     def addSubplots(self, figure):
       if self.specphot is not None and self.stdflux is not None :
-        self.subplot_std_extracted = figure.add_subplot(3,1,1)
-        self.subplot_resp          = figure.add_subplot(3,1,2)
-        self.subplot_std_tabulated = figure.add_subplot(3,1,3)
+        gs = matplotlib.gridspec.GridSpec(100,1)
+        self.subplot_std_extracted = figure.add_subplot(gs[0:25,0])
+        self.subplot_resp          = figure.add_subplot(gs[33:58,0])
+        self.subplot_std_tabulated = figure.add_subplot(gs[66:91,0])
+        self.subplot_txtinfo       = figure.add_subplot(gs[99:100,0])
       else : 
         self.subtext_nodata      = figure.add_subplot(1,1,1)
           
@@ -97,6 +99,9 @@ try:
         #Tabulated data standard star
         self.plotStdTabulated()
 
+        #Additional text info
+        self.showTextInfo()
+
       else :
         #Data not found info
         self.showNoData()
@@ -122,6 +127,32 @@ try:
         self.stdflux.plotStdTabRedFlux(self.subplot_std_tabulated, 
                                        title_std_tabulated, tooltip_std_tabulated)
 
+    def showTextInfo(self) :
+      self.subplot_txtinfo.set_axis_off()
+      try:
+        grism = self.specphot.resp.readKeyword('HIERARCH ESO INS GRIS1 NAME')
+      except:
+        grism = 'unkown'
+      try:
+        filter_name = self.specphot.resp.readKeyword('HIERARCH ESO INS FILT1 NAME')
+      except:
+        filter_name = 'free'
+      self.subplot_txtinfo.text(0.0, 0., 'Grism/Filter: '+grism+'/'+
+                               filter_name, 
+                               ha='left', va='center', weight='bold')
+      try:
+        position  = self.specphot.resp.readKeyword('HIERARCH ESO SEQ SPEC TARG')
+        self.subplot_txtinfo.text(0.38, 0., 'Slit position: '+position, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        std_name = self.specphot.resp.readKeyword('HIERARCH ESO OBS TARG NAME')
+        self.subplot_txtinfo.text(0.7, 0.0, 'Std star name: '+std_name, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+
     def showNoData(self) :
       #Data not found info
       self.subtext_nodata.set_axis_off()
