@@ -66,6 +66,8 @@ try:
       for inst_mode in {'MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU'} :
         if 'SKY_SHIFTS_SLIT_SCI_'+inst_mode in frames:
           self.skylines_off   = PlotableSkylinesOffsets(frames["SKY_SHIFTS_SLIT_SCI_"+inst_mode])
+          if numpy.isnan(self.skylines_off.allwave_res).all() :
+            self.skylines_off = None #All the offsets are NULL, not plotting
           
 
                   
@@ -77,13 +79,16 @@ try:
     def addSubplots(self, figure):
       if self.sci_mapped is not None :
         if self.skylines_off is not None :
-          gs = matplotlib.gridspec.GridSpec(7,7)
-          self.subplot_sci_mapped    = figure.add_subplot(gs[0:2,:])
-          self.subplot_sci_extracted = figure.add_subplot(gs[3:5,:])
-          self.subplot_skylines_off  = figure.add_subplot(gs[6,:])
+          gs = matplotlib.gridspec.GridSpec(100,1)
+          self.subplot_sci_mapped    = figure.add_subplot(gs[0:30,0])
+          self.subplot_sci_extracted = figure.add_subplot(gs[38:68,0])
+          self.subplot_skylines_off  = figure.add_subplot(gs[76:92,0])
+          self.subplot_txtinfo       = figure.add_subplot(gs[95:100,0])
         else :
-          self.subplot_sci_mapped    = figure.add_subplot(2,1,1)
-          self.subplot_sci_extracted = figure.add_subplot(2,1,2)
+          gs = matplotlib.gridspec.GridSpec(100,1)
+          self.subplot_sci_mapped    = figure.add_subplot(gs[0:42,0])
+          self.subplot_sci_extracted = figure.add_subplot(gs[50:90,0])
+          self.subplot_txtinfo       = figure.add_subplot(gs[95:100,0])
       else : 
         self.subtext_nodata      = figure.add_subplot(1,1,1)
           
@@ -109,6 +114,9 @@ try:
         #Sky lines offset
         self.plotSkyLinesOffsets()
 
+        #Additional text info
+        self.showTextInfo()
+
       else :
         #Data not found info
         self.showNoData()
@@ -118,7 +126,7 @@ try:
         tooltip_sci_mapped = """Mapped science (not flux-calibrated).
 The regions of extracted spectra are marked by red 
 (upper boundary of extraction region) 
-and blue (lower boundary) lines. 
+and yellow (lower boundary) lines. 
 By middle-clicking within one of these regions,
 you select an extracted spectrum,
 which will be plotted below."""
@@ -152,9 +160,57 @@ pipeline values as given in the User Manual)
 relative to their reference position. 
 The offsets are adjusted by default by 
 a constant shift (--skyalign parameter)."""
+        if self.sci_extracted is not None:
+          wave_minlim = self.sci_extracted.spectrumdisplay.wave_lim[0]
+          wave_maxlim = self.sci_extracted.spectrumdisplay.wave_lim[1]
+          res_minlim = numpy.nanmin(self.skylines_off.allwave_res)
+          res_maxlim = numpy.nanmax(self.skylines_off.allwave_res)
+          if (res_minlim == res_maxlim) :
+            res_minlim = 0
+            res_maxlim = 2 * res_maxlim
+          self.skylines_off.resdisplay.setLimits(wave_minlim, wave_maxlim,
+                                                 res_minlim, res_maxlim)
         self.skylines_off.plot(self.subplot_skylines_off, title_skylines_off,
                                tooltip_skylines_off)
 
+    def showTextInfo(self) :
+      self.subplot_txtinfo.set_axis_off()
+      try:
+        grism = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS GRIS1 NAME')
+      except:
+        grism = 'unkown'
+      try:
+        filter_name = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS FILT1 NAME')
+      except:
+        filter_name = 'free'
+      self.subplot_txtinfo.text(0.1, 0., 'Grism/Filter: '+grism+'/'+
+                               filter_name, 
+                               ha='left', va='center', weight='bold')
+      try:
+        slit = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS SLIT NAME')
+        self.subplot_txtinfo.text(0.5, 0., 'Slit name (LSS): '+slit, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        checksum = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS MOS CHECKSUM')
+        self.subplot_txtinfo.text(0.5, 0., 'Slits checksum (MOS): '+str(checksum), 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        mask_id = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO INS MASK ID')
+        self.subplot_txtinfo.text(0.5, 0., 'Mask id (MXU): '+mask_id, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+      try:
+        target_name = self.sci_extracted.extractedscience.readKeyword('HIERARCH ESO OBS TARG NAME')
+        self.subplot_txtinfo.text(0.1, 0.6, 'Target name: '+target_name, 
+                               ha='left', va='center', weight='bold')
+      except:
+        pass
+
     def showNoData(self) :
       #Data not found info
       self.subtext_nodata.set_axis_off()
@@ -203,7 +259,7 @@ a constant shift (--skyalign parameter)."""
 
     def setWindowHelp(self):
       help_text = """
-In this window, the user ..."""
+In this window, the user will interact with the Fors science reduction"""
       return help_text
 
     def setWindowTitle(self):
